@@ -1,6 +1,4 @@
 # Opgave 1
-#def generate_labels(n): # Generere liste med n indgange fra mindste til største
-   #return list(range(1, n+1))
 
 import random
 import string
@@ -25,7 +23,10 @@ def permute(L):  # Permutere en givet liste L
 
 # Opgave 3
 def pairs(L):  # Sætter par fra en list L sammen
-    return [(i, k) for i in L for k in L if i < k]
+    if len(L[1]) >= 2:
+        return [(i, k) for i in L for k in L if int(i[1:]) < int(k[1:])]
+    else:
+        return [(i, k) for i in L for k in L if i < k]
 
 
 # Opgave 4
@@ -36,3 +37,8 @@ def canonical_triplets(A,B):  # Laver tuples med element fra A som 0'te indgang
 # Opgave 5
 def anchored_triplets(L, R):  # Sammensætter to tuples
     return canonical_triplets(L, R)+canonical_triplets(R, L)
+
+J = gen_labels_letter(5)
+K = gen_labels(5)
+print(pairs(J))
+print(pairs(K))
\ No newline at end of file
